[arvados] created: 2.7.0-6458-gc19fe27473

git repository hosting git at public.arvados.org
Fri Apr 26 03:37:45 UTC 2024


        at  c19fe27473e7b46504ba82116bd8a019fe23357a (commit)


commit c19fe27473e7b46504ba82116bd8a019fe23357a
Author: Tom Clegg <tom at curii.com>
Date:   Thu Apr 25 23:37:31 2024 -0400

    try things with bundler
    
    Arvados-DCO-1.1-Signed-off-by: Tom Clegg <tom at curii.com>

diff --git a/build/run-library.sh b/build/run-library.sh
index 53e3d0a52c..cb6eaaf3a0 100755
--- a/build/run-library.sh
+++ b/build/run-library.sh
@@ -525,28 +525,11 @@ handle_rails_package() {
         bundle config set deployment true
         # Avoid loading system-wide gems (although this seems to not work 100%).
         bundle config set disable_shared_gems true
-        # `bundle cache` only downloads gems, doesn't install them.
+        bundle install --without test:deployment:production
+        # `bundle package` only downloads gems, doesn't install them.
         # Our Rails postinst script does the install step.
         bundle config set no_install true
-        # As of April 2024/Bundler 2.4, `bundle cache` seems to skip downloading
-        # gems that are already available system-wide... and then it complains
-        # that your bundle is incomplete. Work around this by fetching gems
-        # manually.
-        # TODO: Once all our supported distros have Ruby 3+, we can modify
-        # the awk script to print "NAME:VERSION" output, and pipe that directly
-        # to `xargs -0r gem fetch` for reduced overhead.
-        mkdir -p vendor/cache
-        awk -- '
-BEGIN { OFS="\0"; ORS="\0"; }
-(/^[[:space:]]*$/) { level=0; }
-($0 == "GEM" || $0 == "  specs:") { level+=1; }
-(level == 2 && NF == 2 && $1 ~ /^[[:alpha:]][-_[:alnum:]]*$/ && $2 ~ /^\([[:digit:]]+[-_+.[:alnum:]]*\)$/) {
-    print "--version", substr($2, 2, length($2) - 2), $1;
-}
-' Gemfile.lock | env -C vendor/cache xargs -0r --max-args=3 gem fetch
-        # Despite the bug, we still run `bundle cache` to make sure Bundler is
-        # happy for later steps.
-        bundle cache
+        bundle package
     )
     if [[ 0 != "$?" ]] || ! cd "$WORKSPACE/packages/$TARGET"; then
         echo "ERROR: $pkgname package prep failed" >&2

-----------------------------------------------------------------------


hooks/post-receive
-- 




More information about the arvados-commits mailing list